---
title: <span class="badge object-type-scalar"></span> Degrees
---
# <span class="badge object-type-scalar"></span> Degrees

Angle: Degrees (°)

## Definition

```python
# Angle: Degrees (°)
Degrees: typing.Literal["degree"] = "degree"
```
